/* 

	School to Work and Socioeconomic Status (STOWSES) Project
	Analysis
	Colette Salemi, Caroline Krafft
	Updated 2022.02.20 CK
	
	
		Notes:	Includes regression output (outreg2) for multinomial logit estimation and margins plots 
	
																																						*/	
*	Includes multinomial logit estimates and margins plots 



/****************************************************************************************************************************************************************
	
	EGYPT, MALES
	
****************************************************************************************************************************************************************/

local cs="mene"
local country_code=818
local country="Egypt"
local sex=1
local sex2="Men"

*	MULTINOMIAL LOGIT

use "LMPS SToWSES clean v1.dta", clear

*Men
mlogit worktaxon b4.taxonomy_tot##b1.generation if sex==`sex' & country==`country_code' [aw=expan_indiv] , rrr base(4)
est store `cs'

*	MARGINS PLOTS

*	Family Business

estimates restore `cs'
margins, over(taxonomy_tot generation) predict(outcome(1)) 
marginsplot , level(90)   plotregion(margin(sides))  ///
xtitle("Taxonomy") ytitle("Pr. Family Business") ///
xlabel(1 "Low Ed." ///
2 `""Intermediate" "Ed.""'  ///
3 `""High Ed." "Low SES""' ///
4 `""High Ed." "High SES""' ) ///
plot1opts(lcolor(gs9) lpatt("l") mcolor(gs3)) ///
plot2opts(lcolor(gs4) lpatt(dash) mcolor(gs7)) ///
plot3opts(lcolor(gs1) lpatt(shortdash) mcolor(gs13)) ///
ci1opts(lcolor(gs9)) ///
ci2opts(lcolor(gs4)) ///
ci3opts(lcolor(gs1)) ///
title("`country'") ///
ylabel(0 (.05) .3)
graph save "Graphs/`sex2' `country' Fam Business.gph", replace

*	Informal private sector

estimates restore `cs'
margins, over(taxonomy_tot generation) predict(outcome(2))
marginsplot , level(90)   plotregion(margin(sides))  ///
xtitle("Taxonomy") ytitle("Pr. Informal Private Sector") ///
xlabel(1 "Low Ed." ///
2 `""Intermediate" "Ed.""'  ///
3 `""High Ed." "Low SES""' ///
4 `""High Ed." "High SES""' ) ///
plot1opts(lcolor(gs9) lpatt("l") mcolor(gs3)) ///
plot2opts(lcolor(gs4) lpatt(dash) mcolor(gs7)) ///
plot3opts(lcolor(gs1) lpatt(shortdash) mcolor(gs13)) ///
ci1opts(lcolor(gs9)) ///
ci2opts(lcolor(gs4)) ///
ci3opts(lcolor(gs1)) ///
title("`country'") ///
ylabel(0 (.1) .7)
graph save "Graphs/`sex2' `country' Informal.gph", replace

*	Formal private sector 

estimates restore `cs'
margins, over(taxonomy_tot generation) predict(outcome(3))
marginsplot , level(90)   plotregion(margin(sides))  ///
xtitle("Taxonomy") ytitle("Pr. Formal private sector") ///
xlabel(1 "Low Ed." ///
2 `""Intermediate" "Ed.""'  ///
3 `""High Ed." "Low SES""' ///
4 `""High Ed." "High SES""' ) ///
plot1opts(lcolor(gs9) lpatt("l") mcolor(gs3)) ///
plot2opts(lcolor(gs4) lpatt(dash) mcolor(gs7)) ///
plot3opts(lcolor(gs1) lpatt(shortdash) mcolor(gs13)) ///
ci1opts(lcolor(gs9)) ///
ci2opts(lcolor(gs4)) ///
ci3opts(lcolor(gs1)) ///
title("`country'") ///
ylabel(0 (.1) .4)
graph save "Graphs/`sex2' `country' Formal.gph", replace

*	Public sector

estimates restore `cs'
margins, over(taxonomy_tot generation) predict(outcome(4))
marginsplot , level(90)   plotregion(margin(sides))  ///
xtitle("Taxonomy") ytitle("Pr. Public sector") ///
xlabel(1 "Low Ed." ///
2 `""Intermediate" "Ed.""'  ///
3 `""High Ed." "Low SES""' ///
4 `""High Ed." "High SES""' ) ///
plot1opts(lcolor(gs9) lpatt("l") mcolor(gs3)) ///
plot2opts(lcolor(gs4) lpatt(dash) mcolor(gs7)) ///
plot3opts(lcolor(gs1) lpatt(shortdash) mcolor(gs13)) ///
ci1opts(lcolor(gs9)) ///
ci2opts(lcolor(gs4)) ///
ci3opts(lcolor(gs1)) ///
title("`country'") ///
ylabel(0 (.1) .6)
graph save "Graphs/`sex2' `country' Public.gph", replace

*	Not yet worked

estimates restore `cs'
margins, over(taxonomy_tot generation) predict(outcome(5))
marginsplot , level(90)   plotregion(margin(sides))  ///
xtitle("Taxonomy") ytitle("Pr. Not yet worked") ///
xlabel(1 "Low Ed." ///
2 `""Intermediate" "Ed.""'  ///
3 `""High Ed." "Low SES""' ///
4 `""High Ed." "High SES""' ) ///
plot1opts(lcolor(gs9) lpatt("l") mcolor(gs3)) ///
plot2opts(lcolor(gs4) lpatt(dash) mcolor(gs7)) ///
plot3opts(lcolor(gs1) lpatt(shortdash) mcolor(gs13)) ///
ci1opts(lcolor(gs9)) ///
ci2opts(lcolor(gs4)) ///
ci3opts(lcolor(gs1)) ///
title("`country'") ///
ylabel(0 (.1) .8)
graph save "Graphs/`sex2' `country' No work.gph", replace

/****************************************************************************************************************************************************************
	
	TUNISIA: MEN
	
****************************************************************************************************************************************************************/

local cs="ment"
local country_code=788
local country="Tunisia"
local sex=1
local sex2="Men"

*	MULTINOMIAL LOGIT

use "LMPS SToWSES clean v1.dta", clear


mlogit worktaxon b4.taxonomy_tot##b1.generation if sex==`sex' & country==`country_code' [aw=expan_indiv] , rrr base(4)
est store `cs'

*	MARGINS PLOTS

*	Family Business
estimates restore `cs'
margins, over(taxonomy_tot generation) predict(outcome(1))
marginsplot , level(90)   plotregion(margin(sides))  ///
xtitle("Taxonomy") ytitle("Pr. Family Business") ///
xlabel(1 "Low Ed." ///
2 `""Intermediate" "Ed.""'  ///
3 `""High Ed." "Low SES""' ///
4 `""High Ed." "High SES""' ) ///
plot1opts(lcolor(gs9) lpatt("l") mcolor(gs3)) ///
plot2opts(lcolor(gs4) lpatt(dash) mcolor(gs7)) ///
plot3opts(lcolor(gs1) lpatt(shortdash) mcolor(gs13)) ///
ci1opts(lcolor(gs9)) ///
ci2opts(lcolor(gs4)) ///
ci3opts(lcolor(gs1)) ///
title("`country'") ///
ylabel(0 (.05) .3)
graph save "Graphs/`sex2' `country' Fam Business.gph", replace

*	Informal private sector

estimates restore `cs'
margins, over(taxonomy_tot generation) predict(outcome(2))
marginsplot , level(90)   plotregion(margin(sides))  ///
xtitle("Taxonomy") ytitle("Pr. Informal Private Sector") ///
xlabel(1 "Low Ed." ///
2 `""Intermediate" "Ed.""'  ///
3 `""High Ed." "Low SES""' ///
4 `""High Ed." "High SES""' ) ///
plot1opts(lcolor(gs9) lpatt("l") mcolor(gs3)) ///
plot2opts(lcolor(gs4) lpatt(dash) mcolor(gs7)) ///
plot3opts(lcolor(gs1) lpatt(shortdash) mcolor(gs13)) ///
ci1opts(lcolor(gs9)) ///
ci2opts(lcolor(gs4)) ///
ci3opts(lcolor(gs1)) ///
title("`country'") ///
ylabel(0 (.1) .7)
graph save "Graphs/`sex2' `country' Informal.gph", replace

*	Formal private sector 

estimates restore `cs'
margins, over(taxonomy_tot generation) predict(outcome(3))
marginsplot , level(90)   plotregion(margin(sides))  ///
xtitle("Taxonomy") ytitle("Pr. Formal private sector") ///
xlabel(1 "Low Ed." ///
2 `""Intermediate" "Ed.""'  ///
3 `""High Ed." "Low SES""' ///
4 `""High Ed." "High SES""' ) ///
plot1opts(lcolor(gs9) lpatt("l") mcolor(gs3)) ///
plot2opts(lcolor(gs4) lpatt(dash) mcolor(gs7)) ///
plot3opts(lcolor(gs1) lpatt(shortdash) mcolor(gs13)) ///
ci1opts(lcolor(gs9)) ///
ci2opts(lcolor(gs4)) ///
ci3opts(lcolor(gs1)) ///
title("`country'") ///
ylabel(0 (.1) .4)
graph save "Graphs/`sex2' `country' Formal.gph", replace

*	Public sector

estimates restore `cs'
margins, over(taxonomy_tot generation) predict(outcome(4))
marginsplot , level(90)   plotregion(margin(sides))  ///
xtitle("Taxonomy") ytitle("Pr. Public sector") ///
xlabel(1 "Low Ed." ///
2 `""Intermediate" "Ed.""'  ///
3 `""High Ed." "Low SES""' ///
4 `""High Ed." "High SES""' ) ///
plot1opts(lcolor(gs9) lpatt("l") mcolor(gs3)) ///
plot2opts(lcolor(gs4) lpatt(dash) mcolor(gs7)) ///
plot3opts(lcolor(gs1) lpatt(shortdash) mcolor(gs13)) ///
ci1opts(lcolor(gs9)) ///
ci2opts(lcolor(gs4)) ///
ci3opts(lcolor(gs1)) ///
title("`country'") ///
ylabel(0 (.1) .6)
graph save "Graphs/`sex2' `country' Public.gph", replace

*	Not yet worked

estimates restore `cs'
margins, over(taxonomy_tot generation) predict(outcome(5))
marginsplot , level(90)   plotregion(margin(sides))  ///
xtitle("Taxonomy") ytitle("Pr. Not yet worked") ///
xlabel(1 "Low Ed." ///
2 `""Intermediate" "Ed.""'  ///
3 `""High Ed." "Low SES""' ///
4 `""High Ed." "High SES""' ) ///
plot1opts(lcolor(gs9) lpatt("l") mcolor(gs3)) ///
plot2opts(lcolor(gs4) lpatt(dash) mcolor(gs7)) ///
plot3opts(lcolor(gs1) lpatt(shortdash) mcolor(gs13)) ///
ci1opts(lcolor(gs9)) ///
ci2opts(lcolor(gs4)) ///
ci3opts(lcolor(gs1)) ///
title("`country'") ///
ylabel(0 (.1) .8)
graph save "Graphs/`sex2' `country' No work.gph", replace

/****************************************************************************************************************************************************************
	
	JORDAN - MEN
	
****************************************************************************************************************************************************************/

local cs="menj"
local country_code=400
local country="Jordan"
local sex=1
local sex2="Men"

*	MULTINOMIAL LOGIT

use "LMPS SToWSES clean v1.dta", clear

mlogit worktaxon b4.taxonomy_tot##b1.generation if sex==`sex' & country==`country_code' [aw=expan_indiv] , rrr base(4)
est store `cs'


*	MARGINS PLOTS

*	Family Business
estimates restore `cs'
margins, over(taxonomy_tot generation) predict(outcome(1))
marginsplot , level(90)   plotregion(margin(sides))  ///
xtitle("Taxonomy") ytitle("Pr. Family Business") ///
xlabel(1 "Low Ed." ///
2 `""Intermediate" "Ed.""'  ///
3 `""High Ed." "Low SES""' ///
4 `""High Ed." "High SES""' ) ///
plot1opts(lcolor(gs9) lpatt("l") mcolor(gs3)) ///
plot2opts(lcolor(gs4) lpatt(dash) mcolor(gs7)) ///
plot3opts(lcolor(gs1) lpatt(shortdash) mcolor(gs13)) ///
ci1opts(lcolor(gs9)) ///
ci2opts(lcolor(gs4)) ///
ci3opts(lcolor(gs1)) ///
title("`country'") ///
ylabel(0 (.05) .3)
graph save "Graphs/`sex2' `country' Fam Business.gph", replace

*	Informal private sector

estimates restore `cs'
margins, over(taxonomy_tot generation) predict(outcome(2))
marginsplot , level(90)   plotregion(margin(sides))  ///
xtitle("Taxonomy") ytitle("Pr. Informal Private Sector") ///
xlabel(1 "Low Ed." ///
2 `""Intermediate" "Ed.""'  ///
3 `""High Ed." "Low SES""' ///
4 `""High Ed." "High SES""' ) ///
plot1opts(lcolor(gs9) lpatt("l") mcolor(gs3)) ///
plot2opts(lcolor(gs4) lpatt(dash) mcolor(gs7)) ///
plot3opts(lcolor(gs1) lpatt(shortdash) mcolor(gs13)) ///
ci1opts(lcolor(gs9)) ///
ci2opts(lcolor(gs4)) ///
ci3opts(lcolor(gs1)) ///
title("`country'") ///
ylabel(0 (.1) .7)
graph save "Graphs/`sex2' `country' Informal.gph", replace

*	Formal private sector 

estimates restore `cs'
margins, over(taxonomy_tot generation) predict(outcome(3))
marginsplot , level(90)   plotregion(margin(sides))  ///
xtitle("Taxonomy") ytitle("Pr. Formal private sector") ///
xlabel(1 "Low Ed." ///
2 `""Intermediate" "Ed.""'  ///
3 `""High Ed." "Low SES""' ///
4 `""High Ed." "High SES""' ) ///
plot1opts(lcolor(gs9) lpatt("l") mcolor(gs3)) ///
plot2opts(lcolor(gs4) lpatt(dash) mcolor(gs7)) ///
plot3opts(lcolor(gs1) lpatt(shortdash) mcolor(gs13)) ///
ci1opts(lcolor(gs9)) ///
ci2opts(lcolor(gs4)) ///
ci3opts(lcolor(gs1)) ///
title("`country'") ///
ylabel(0 (.1) .4)
graph save "Graphs/`sex2' `country' Formal.gph", replace

*	Public sector

estimates restore `cs'
margins, over(taxonomy_tot generation) predict(outcome(4))
marginsplot , level(90)   plotregion(margin(sides))  ///
xtitle("Taxonomy") ytitle("Pr. Public sector") ///
xlabel(1 "Low Ed." ///
2 `""Intermediate" "Ed.""'  ///
3 `""High Ed." "Low SES""' ///
4 `""High Ed." "High SES""' ) ///
plot1opts(lcolor(gs9) lpatt("l") mcolor(gs3)) ///
plot2opts(lcolor(gs4) lpatt(dash) mcolor(gs7)) ///
plot3opts(lcolor(gs1) lpatt(shortdash) mcolor(gs13)) ///
ci1opts(lcolor(gs9)) ///
ci2opts(lcolor(gs4)) ///
ci3opts(lcolor(gs1)) ///
title("`country'") ///
ylabel(0 (.1) .6)
graph save "Graphs/`sex2' `country' Public.gph", replace

*	Not yet worked

estimates restore `cs'
margins, over(taxonomy_tot generation) predict(outcome(5))
marginsplot , level(90)   plotregion(margin(sides))  ///
xtitle("Taxonomy") ytitle("Pr. Not yet worked") ///
xlabel(1 "Low Ed." ///
2 `""Intermediate" "Ed.""'  ///
3 `""High Ed." "Low SES""' ///
4 `""High Ed." "High SES""' ) ///
plot1opts(lcolor(gs9) lpatt("l") mcolor(gs3)) ///
plot2opts(lcolor(gs4) lpatt(dash) mcolor(gs7)) ///
plot3opts(lcolor(gs1) lpatt(shortdash) mcolor(gs13)) ///
ci1opts(lcolor(gs9)) ///
ci2opts(lcolor(gs4)) ///
ci3opts(lcolor(gs1)) ///
title("`country'") ///
ylabel(0 (.1) .8)
graph save "Graphs/`sex2' `country' No work.gph", replace

/****************************************************************************************************************************************************************
	
	TABLE A2: MALES IN JORDAN, EGYPT, TUNISIA
	
****************************************************************************************************************************************************************/


esttab mene ment menj using "Graphs/Mlogit_Males.csv", ///
cells(b(star fmt(%9.3f)) se(par))  ///     
stats(N, fmt(%9.0g)) label star(* 0.10 ** 0.05 *** 0.001)  ///
nobase ///
interact(*) ///
refcat(1.edtaxon "Education taxonomy (High ed. high SES omit)" ///
2.generation "Generation (Oldest omit)" ///
1.edtaxon#2.generation "Ed. Taxon. * Generation (High ed. high SES omit + Oldest generation Omit.)")  ///
legend  mlabel("Egypt" "Tunisia" "Jordan") ///
eform ///
replace


/****************************************************************************************************************************************************************
	
	EGYPT - WOMEN
	
****************************************************************************************************************************************************************/

local cs="womene"
local country_code=818
local country="Egypt"
local sex=2
local sex2="Women"

*	MULTINOMIAL LOGIT

use "LMPS SToWSES clean v1.dta", clear

mlogit worktaxonf b4.taxonomy_tot##b1.generation if sex==`sex' & country==`country_code' [aw=expan_indiv] , rrr base(3)
est store `cs'

*	MARGINS PLOTS

*	Private Sector
estimates restore `cs'
margins, over(taxonomy_tot generation) predict(outcome(1))
marginsplot , level(90)   plotregion(margin(sides))  ///
xtitle("Taxonomy") ytitle("Pr. Private Sector") ///
xlabel(1 "Low Ed." ///
2 `""Intermediate" "Ed.""'  ///
3 `""High Ed." "Low SES""' ///
4 `""High Ed." "High SES""' ) ///
plot1opts(lcolor(gs9) lpatt("l") mcolor(gs3)) ///
plot2opts(lcolor(gs4) lpatt(dash) mcolor(gs7)) ///
plot3opts(lcolor(gs1) lpatt(shortdash) mcolor(gs13)) ///
ci1opts(lcolor(gs9)) ///
ci2opts(lcolor(gs4)) ///
ci3opts(lcolor(gs1)) ///
title("`country'") ///
ylabel(0 (.1) .3)
graph save "Graphs/`sex2' `country' Private Sector.gph", replace

*	Public Sector

estimates restore `cs'
margins, over(taxonomy_tot generation) predict(outcome(2))
marginsplot , level(90)   plotregion(margin(sides))  ///
xtitle("Taxonomy") ytitle("Pr. Public Sector") ///
xlabel(1 "Low Ed." ///
2 `""Intermediate" "Ed.""'  ///
3 `""High Ed." "Low SES""' ///
4 `""High Ed." "High SES""' ) ///
plot1opts(lcolor(gs9) lpatt("l") mcolor(gs3)) ///
plot2opts(lcolor(gs4) lpatt(dash) mcolor(gs7)) ///
plot3opts(lcolor(gs1) lpatt(shortdash) mcolor(gs13)) ///
ci1opts(lcolor(gs9)) ///
ci2opts(lcolor(gs4)) ///
ci3opts(lcolor(gs1)) ///
title("`country'") ///
ylabel(0 (.1) .5)
graph save "Graphs/`sex2' `country' Public Sector.gph", replace

*	Not yet worked 

estimates restore `cs'
margins, over(taxonomy_tot generation) predict(outcome(3))
marginsplot , level(90)   plotregion(margin(sides))  ///
xtitle("Taxonomy") ytitle("Pr. Not yet worked") ///
xlabel(1 "Low Ed." ///
2 `""Intermediate" "Ed.""'  ///
3 `""High Ed." "Low SES""' ///
4 `""High Ed." "High SES""' ) ///
plot1opts(lcolor(gs9) lpatt("l") mcolor(gs3)) ///
plot2opts(lcolor(gs4) lpatt(dash) mcolor(gs7)) ///
plot3opts(lcolor(gs1) lpatt(shortdash) mcolor(gs13)) ///
ci1opts(lcolor(gs9)) ///
ci2opts(lcolor(gs4)) ///
ci3opts(lcolor(gs1)) ///
title("`country'") ///
ylabel(0 (.2) 1)
graph save "Graphs/`sex2' `country' Not yet worked.gph", replace

/****************************************************************************************************************************************************************
	
	TUNISIA - WOMEN
	
****************************************************************************************************************************************************************/

local cs="woment"
local country_code=788
local country="Tunisia"
local sex=2
local sex2="Women"

*	MARGINS PLOTS

use "LMPS SToWSES clean v1.dta", clear

mlogit worktaxonf b4.taxonomy_tot##b1.generation if sex==`sex' & country==`country_code' [aw=expan_indiv] , rrr base(3)
est store `cs'

*	Private Sector
estimates restore `cs'
margins, over(taxonomy_tot generation) predict(outcome(1))
marginsplot , level(90)   plotregion(margin(sides))  ///
xtitle("Taxonomy") ytitle("Pr. Private Sector") ///
xlabel(1 "Low Ed." ///
2 `""Intermediate" "Ed.""'  ///
3 `""High Ed." "Low SES""' ///
4 `""High Ed." "High SES""' ) ///
plot1opts(lcolor(gs9) lpatt("l") mcolor(gs3)) ///
plot2opts(lcolor(gs4) lpatt(dash) mcolor(gs7)) ///
plot3opts(lcolor(gs1) lpatt(shortdash) mcolor(gs13)) ///
ci1opts(lcolor(gs9)) ///
ci2opts(lcolor(gs4)) ///
ci3opts(lcolor(gs1)) ///
title("`country'") ///
ylabel(0 (.1) .3)
graph save "Graphs/`sex2' `country' Private Sector.gph", replace

*	Public Sector

estimates restore `cs'
margins, over(taxonomy_tot generation) predict(outcome(2))
marginsplot , level(90)   plotregion(margin(sides))  ///
xtitle("Taxonomy") ytitle("Pr. Public Sector") ///
xlabel(1 "Low Ed." ///
2 `""Intermediate" "Ed.""'  ///
3 `""High Ed." "Low SES""' ///
4 `""High Ed." "High SES""' ) ///
plot1opts(lcolor(gs9) lpatt("l") mcolor(gs3)) ///
plot2opts(lcolor(gs4) lpatt(dash) mcolor(gs7)) ///
plot3opts(lcolor(gs1) lpatt(shortdash) mcolor(gs13)) ///
ci1opts(lcolor(gs9)) ///
ci2opts(lcolor(gs4)) ///
ci3opts(lcolor(gs1)) ///
title("`country'") ///
ylabel(0 (.1) .5)
graph save "Graphs/`sex2' `country' Public Sector.gph", replace

*	Not yet worked 

estimates restore `cs'
margins, over(taxonomy_tot generation) predict(outcome(3))
marginsplot , level(90)   plotregion(margin(sides))  ///
xtitle("Taxonomy") ytitle("Pr. Not yet worked") ///
xlabel(1 "Low Ed." ///
2 `""Intermediate" "Ed.""'  ///
3 `""High Ed." "Low SES""' ///
4 `""High Ed." "High SES""' ) ///
plot1opts(lcolor(gs9) lpatt("l") mcolor(gs3)) ///
plot2opts(lcolor(gs4) lpatt(dash) mcolor(gs7)) ///
plot3opts(lcolor(gs1) lpatt(shortdash) mcolor(gs13)) ///
ci1opts(lcolor(gs9)) ///
ci2opts(lcolor(gs4)) ///
ci3opts(lcolor(gs1)) ///
title("`country'") ///
ylabel(0 (.2) 1)
graph save "Graphs/`sex2' `country' Not yet worked.gph", replace

/****************************************************************************************************************************************************************
	
	JORDAN - WOMEN
	
****************************************************************************************************************************************************************/

local cs="womenj"
local country_code=400
local country="Jordan"
local sex=2
local sex2="Women"

*	MARGINS PLOTS

use "LMPS SToWSES clean v1.dta", clear

mlogit worktaxonf b4.taxonomy_tot##b1.generation if sex==`sex' & country==`country_code' [aw=expan_indiv] , rrr base(3)
est store `cs'

*	Private Sector
estimates restore `cs'
margins, over(taxonomy_tot generation) predict(outcome(1))
marginsplot , level(90)   plotregion(margin(sides))  ///
xtitle("Taxonomy") ytitle("Pr. Private Sector") ///
xlabel(1 "Low Ed." ///
2 `""Intermediate" "Ed.""'  ///
3 `""High Ed." "Low SES""' ///
4 `""High Ed." "High SES""' ) ///
plot1opts(lcolor(gs9) lpatt("l") mcolor(gs3)) ///
plot2opts(lcolor(gs4) lpatt(dash) mcolor(gs7)) ///
plot3opts(lcolor(gs1) lpatt(shortdash) mcolor(gs13)) ///
ci1opts(lcolor(gs9)) ///
ci2opts(lcolor(gs4)) ///
ci3opts(lcolor(gs1)) ///
title("`country'") ///
ylabel(0 (.1) .3)
graph save "Graphs/`sex2' `country' Private Sector.gph", replace

*	Public Sector

estimates restore `cs'
margins, over(taxonomy_tot generation) predict(outcome(2))
marginsplot , level(90)   plotregion(margin(sides))  ///
xtitle("Taxonomy") ytitle("Pr. Public Sector") ///
xlabel(1 "Low Ed." ///
2 `""Intermediate" "Ed.""'  ///
3 `""High Ed." "Low SES""' ///
4 `""High Ed." "High SES""' ) ///
plot1opts(lcolor(gs9) lpatt("l") mcolor(gs3)) ///
plot2opts(lcolor(gs4) lpatt(dash) mcolor(gs7)) ///
plot3opts(lcolor(gs1) lpatt(shortdash) mcolor(gs13)) ///
ci1opts(lcolor(gs9)) ///
ci2opts(lcolor(gs4)) ///
ci3opts(lcolor(gs1)) ///
title("`country'") ///
ylabel(0 (.1) .5)
graph save "Graphs/`sex2' `country' Public Sector.gph", replace

*	Not yet worked 

estimates restore `cs'
margins, over(taxonomy_tot generation) predict(outcome(3))
marginsplot , level(90)   plotregion(margin(sides))  ///
xtitle("Taxonomy") ytitle("Pr. Not yet worked") ///
xlabel(1 "Low Ed." ///
2 `""Intermediate" "Ed.""'  ///
3 `""High Ed." "Low SES""' ///
4 `""High Ed." "High SES""' ) ///
plot1opts(lcolor(gs9) lpatt("l") mcolor(gs3)) ///
plot2opts(lcolor(gs4) lpatt(dash) mcolor(gs7)) ///
plot3opts(lcolor(gs1) lpatt(shortdash) mcolor(gs13)) ///
ci1opts(lcolor(gs9)) ///
ci2opts(lcolor(gs4)) ///
ci3opts(lcolor(gs1)) ///
title("`country'") ///
ylabel(0 (.2) 1)
graph save "Graphs/`sex2' `country' Not yet worked.gph", replace

/****************************************************************************************************************************************************************
	
	TABLE A3: FEMALES IN JORDAN, EGYPT, TUNISIA
	
****************************************************************************************************************************************************************/


esttab womene woment womenj using "Graphs/Mlogit_Females.csv", ///
cells(b(star fmt(%9.3f)) se(par))  ///     
stats(N, fmt(%9.0g)) label star(* 0.10 ** 0.05 *** 0.001) ///
nobase ///
interact(*) ///
refcat(1.edtaxon "Education taxonomy (High ed. high SES omit)" ///
2.generation "Generation (Oldest omit)" ///
1.edtaxon#2.generation "Ed. Taxon. * Generation (High ed. high SES omit + Oldest generation Omit.)")  ///
legend  mlabel("Egypt" "Tunisia" "Jordan") ///
eform ///
replace


****************************************************************************************************************************************************************/
****************************************************************************************************************************************************************/
****************************************************************************************************************************************************************/
*	COMBINING GRAPHS: MARGINS PLOTS		COMBINING GRAPHS: MARGINS PLOTS		COMBINING GRAPHS: MARGINS PLOTS		COMBINING GRAPHS: MARGINS PLOTS		COMBINING GR
****************************************************************************************************************************************************************/
****************************************************************************************************************************************************************/
****************************************************************************************************************************************************************/


*	MALES
 
	* 	Family business
	grc1leg "Graphs/Men Egypt Fam Business" ///
			 "Graphs/Men Jordan Fam Business" ///
			 "Graphs/Men Tunisia Fam Business"
			 
	graph save "Graphs/Margins Men Famly Bus.gph", replace			 
	graph export "Graphs/Margins Men Famly Bus.png", replace width(900)

	*	Informal private
	grc1leg "Graphs/Men Egypt Informal" ///
	"Graphs/Men Jordan Informal" ///
	"Graphs/Men Tunisia Informal" 

	graph export "Graphs/Margins Men Informal.png", replace
	graph export "Graphs/Margins Men Informal.png", replace  width(900)

	*	Formal private
	grc1leg "Graphs/Men Egypt Formal" ///
			"Graphs/Men Jordan Formal" ///
			"Graphs/Men Tunisia Formal" 
			
	graph save "Graphs/Margins Men Formal.gph", replace 
	graph export "Graphs/Margins Men Formal.png", replace  width(900)

	*	Public
	grc1leg "Graphs/Men Egypt Public" ///
			"Graphs/Men Jordan Public" ///
			"Graphs/Men Tunisia Public" 

	graph save "Graphs/Margins Men Public.gph", replace  
	graph export "Graphs/Margins Men Public.png", replace  width(900)

	*	No work
	grc1leg "Graphs/Men Egypt No Work" ///
			"Graphs/Men Jordan No Work" ///
			"Graphs/Men Tunisia No Work" 
			
	graph save "Graphs/Margins Men No work.gph", replace  
	graph export "Graphs/Margins Men No work.png", replace  width(900)



*	FEMALES
 

	*	Private
	grc1leg "Graphs/Women Egypt Private Sector" ///
			"Graphs/Women Jordan Private Sector" ///
			"Graphs/Women Tunisia Private Sector" 

	graph save "Graphs/Margins Women Private Sector.gph", replace  
	graph export "Graphs/Margins Women Private Sector.png", replace  width(900)

	*	Public
	grc1leg "Graphs/Women Egypt Public Sector" ///
			"Graphs/Women Jordan Public Sector" ///
			"Graphs/Women Tunisia Public Sector" 

	graph save "Graphs/Margins Women Public Sector.gph", replace		
	graph export "Graphs/Margins Women Public Sector.png", replace  width(900)

	*	No work
	grc1leg "Graphs/Women Egypt Not yet worked" ///
			"Graphs/Women Jordan Not yet worked" ///
			"Graphs/Women Tunisia Not yet worked" 
			
	graph save "Graphs/Margins Women Not yet worked.gph", replace
	graph export "Graphs/Margins Women Not yet worked.png", replace  width(900)
