/* 

	School to Work and Socioeconomic Status (STOWSES) Project
	Data cleaning
	Colette Salemi, Caroline Krafft
	Revised 2022.07.29 CS
	*/
	
/* 
	Notes:	For Jordan and Egypt, 	taxonomy categories are 	(1) Less than secondary (2) Secondary education
																(3) higher education, low SES (4) higher education, low SES
															
									low and high SES are		Low SES: 	One parent or both parents do not have a basic education or higher, and father does not 
																			hold a professional, managerial, technical, clerical, or sales job.
																High SES: 	Both parents have a basic education or higher, or father holds a professional, 
																			managerial, technical, clerical, or sales job.
									
									variable name: taxonomy1
									

									
									
			For Tunisia, 			taxonomy categories are 	(1) Less than basic education (2) basic education (3) Entered secondary, low SES 
																(4) Entered secondary, +, high SES
																
									low and high SES are		Low SES:	Neither parent has a basic education
																High SES:	At least one parent has a basic education
														
									
									
									variable name: taxonomy_t
									
			
			Combined taxonomy categories are					(1) Low education (2) Middle education (3) High education, low SES (4) High education, high SES
			
								
									variable name: taxonomy_tot
								
								
			
			Cohorts 											are defined based on "year of school exit", which is last year individual went to school, or the 
																year the individual turned 15, whichever came last. We focus on those who made their exit
																three years before the survey or earlier, to give job seekers time to find a job.
																
																The cohorts are:
																(1) Youngest generation: school exit 3-12 years prior to survey
																		Egypt 2000-2009
																		Jordan 2004-2013
																		Tunisia 2002-2011
																(2) Middle generation: school exit 13-22 years prior to survey
																		Egypt 1990-1999
																		Jordan 1994-2003
																		Tunisia 1992-2001
																(3) Oldest generation: school exit 23-32 years prior to survey
																		Egypt 1980-1989
																		Jordan 1984-1993 
																		Tunisia 1982-1991
									variable name: generation
								
								
			First jobs											are defined based on a three year window after school exit
			
			
									variable name: worktaxon
*/

/****************************************************************************************************************************************************************
	
	Extract additional schooling data from TLMPS14 to use for TLMPS taxonomy variable 4 and from Jordan and Egypt to identify year of school exit
		
		For all countries we extract the year of school exit
		For Tunisia we also extract whether the individual ever entered secondary school
		
****************************************************************************************************************************************************************/

*TUNISIA
	use "Original data/TLMPS 2014 v2.1 all.dta", replace
	
	replace brthyr=2014-age if brthyr==. & age!=.
	
	gen last_ed=.
	*Code to year age 15 if person never went to school
	replace last_ed=brthyr+15 if gotosch==1 & brthyr!=.
	
	*Code to year of exit of first level of school if person went to school, entered and exited once
	replace last_ed=v206_1_2 if gotosch==2 & v206_1_2!=. 
	
	*Code to year of exit of second level of school if person went to school, entered and exited twice
	replace last_ed=v206_2_2 if gotosch==2 & v206_2_2!=.
	
	*Code to year of exit of third level of school if person went to school, entered and exited thrice
	replace last_ed=v206_3_2 if gotosch==2 & v206_3_2!=.
	
	*Code to year of exit of fourth level of school if person went to school, entered and exited four times
	replace last_ed=v206_4_2 if gotosch==2 & v206_4_2!=. 
	
	*Impute with years of school if still missing
	replace last_ed=brthyr+6+yrschl if gotosch==2 & last_ed==. & brthyr!=. & yrschl!=.
	
	*Code to year age 15 if exited before 15th birthday
	replace last_ed = brthyr+15 if gotosch==2	& brthyr!=. & last_ed!=.  & ((brthyr+15) > last_ed)
	
	*Clean
	replace last_ed=. if last_ed>2014

	*Check if missing lack underlying
	tabu last_ed if age>=15 & age<=64, miss
	tabu last_ed gotosch if age>=15 & age<=64 & gotosch!=3 & gotosch!=., miss
	tabu v206_1_2 if age>=15 & age<=64 & gotosch==2 & last_ed==., miss
	tabu yrschl if age>=15 & age<=64 & gotosch==2 & last_ed==., miss
	
	rename last_ed last_ed_t
	
	keep indid country lastlevel last_ed_t
	egen banana=concat(country indid)
	drop indid
	rename banana indid
	save "Additional data/Tunisia abridged.dta", replace

*JORDAN
	use "Original data/JLMPS 2016 xs v1.1.dta", replace
	
	keep if nationality_cl==1
	
	
	gen last_ed=.
	*Code to year age 15 if person never went to school
	replace last_ed = brthyr + 15 if everattd==0 & brthyr!=.
	
	*Terminal year of schooling for those who never missed a year of school
	replace last_ed = q2128 if everattd==1 & q2128!=. & q2128!=9998
	replace last_ed = q2129 + brthyr if everattd==1 & q2129!=.
	
	*Terminal year of schooling for those who missed 1+ years of school
	replace last_ed = q2133 if everattd==1 & last_ed==. 
	replace last_ed = q2134 + brthyr if everattd==1 & last_ed==. 
	
	*Impute with years of school if still missing
	replace last_ed=brthyr+6+yrschl if q2127==2 & everattd!=0 & last_ed==. & brthyr!=. & yrschl!=.
	
	*Code to year age 15 if school exit preceded individual turning 15
	replace last_ed = brthyr + 15 if everattd==1 & last_ed!=. & brthyr!=. & ((brthyr + 15) > last_ed)
	
	*Missing if individual still in school
	replace last_ed= . if q2127==1
	
	*Clean
	replace last_ed=. if last_ed>2016
	
	tabu last_ed if age>=15 & age<=64 & q2127!=1, miss
	
	rename last_ed last_ed_j
	
	keep indid last_ed_j
	gen country=400
	egen banana=concat(country indid)
	drop indid
	rename banana indid
	save "Additional data/Jordan abridged.dta", replace

	
*EGYPT
	use "Original data/elmps 2012 xs v2.3 all.dta", replace
	gen last_ed=.
	*Code to year age 15 if person never went to school
	replace last_ed=brthyr + 15 if yrschl==0 & brthyr!=. 
	
	*Code to year of exit 
	egen last_ed_temp=rowmax(e1end e2end e3end e4end e5end)
	replace last_ed=last_ed_temp if student==2 & yrschl!=0 & last_ed_temp!=.
	
	*Impute with years of school if still missing
	replace last_ed=brthyr+6+yrschl if student==2 & yrschl!=0 & last_ed==. & brthyr!=. & yrschl!=.
	
	*Code to year age 15 if individual exited school before turning 15
	replace last_ed=brthyr + 15 if brthyr!=. & student==2 & last_ed!=. & ((brthyr + 15) > last_ed)
	
	*Clean
	replace last_ed=. if last_ed>2012
	
	tabu last_ed if age>=15 & age<=64 & student==2, miss
	
	rename last_ed last_ed_e
	
	keep indid last_ed_e
	gen country=818
	egen banana=concat(country indid)
	drop indid
	rename banana indid
	save "Additional data/Egypt abridged.dta", replace
	

	
	use "Original data/Integrated LMPs v3.0.dta", replace
	
	merge m:1 indid using "Additional data/Tunisia abridged.dta"
	drop _merge
	merge m:1 indid using "Additional data/Jordan abridged.dta"
	drop _merge
	merge m:1 indid using "Additional data/Egypt abridged.dta", force

	
	gen last_ed=.
	replace last_ed=last_ed_t if country==788 
	replace last_ed=last_ed_j if country==400
	replace last_ed=last_ed_e if country==818
	keep if last_ed!=.
	
	la var last_ed "year individual exited education, or year turned 15"
	

/****************************************************************************************************************************************************************
	
	Cleaning for years and nationalities
	
****************************************************************************************************************************************************************/
	
	
	keep if round==2016 | round==2014 | round==2012
	drop if nationality_cl!=1 & country==400

/****************************************************************************************************************************************************************
	
	Construct age cohort variable
	
****************************************************************************************************************************************************************/
	
	
	gen generation=.
	replace generation=3 if country==818 & last_ed>=2000 & last_ed<=2009
	replace generation=2 if country==818 & last_ed>=1990 & last_ed<=1999
	replace generation=1 if country==818 & last_ed>=1980 & last_ed<=1989
	
	replace generation=3 if country==788 & last_ed>=2002 & last_ed<=2011
	replace generation=2 if country==788 & last_ed>=1992 & last_ed<=2001
	replace generation=1 if country==788 & last_ed>=1982 & last_ed<=1991
	
	replace generation=3 if country==400 & last_ed>=2004 & last_ed<=2013
	replace generation=2 if country==400 & last_ed>=1994 & last_ed<=2003
	replace generation=1 if country==400 & last_ed>=1984 & last_ed<=1994
	
	la def omy 3 "Youngest" 2 "Middle" 1 "Oldest"
	la val generation omy
	la var generation "Ind'ls generation based on yr. sch. exit or yr. turned 15"
	
/****************************************************************************************************************************************************************
	
	Construct upper and lower SES variable for Jordan and Egypt
	
		Upper SES includes those for whom both parents have a basic education
		or higher or whose fathers work in professional, managerial, technical, 
		clerical or sales occupations (or armed forces in Jordan).
	
****************************************************************************************************************************************************************/
	
	gen med=.
	replace med=0 if mteducst<3 & mteducst!=.
	replace med=1 if mteducst>=3 & mteducst!=.
	
	ta mteducst med, miss
	
	gen fed=.
	replace fed=0 if fteducst<3 & fteducst!=.
	replace fed=1 if fteducst>=3 & fteducst!=.
	
	ta fteducst fed, miss
	
	gen focc=.
	replace focc=1 if ftocp1d>=0 & ftocp1d<=5 & ftocp1d!=.
	replace focc=0 if ftocp1d>=6 & ftocp1d<=9 & ftocp1d!=.
	
	ta ftocp1d focc, miss
	
	
	
/****************************************************************************************************************************************************************
	
	Construct SToWSES taxonomy - Jordan and Egypt
	
		Categories are: (1) Less than secondary education 
						(2) secondary 
						(3) higher education, low SES (one or more parents has less than a basic education and father does not have high skilled occupation)
						(4) higher education, high SES (both parents basic OR father has high skilled occupation)
	
****************************************************************************************************************************************************************/

	gen ses1=0
	replace ses1=1 if (med==1 & fed==1) | focc==1
	la def ses1 0 "low SES" 1 "high SES"
	la val ses1 ses1


	gen taxonomy1=.
	replace taxonomy1=1 if educ1d<=3 & educ1d!=.
	replace taxonomy1=2 if educ1d==4
	replace taxonomy1=3 if educ1d>=5 & educ1d<=7 & ses1==0 
	replace taxonomy1=4 if educ1d>=5 & educ1d<=7 & ses1==1 
	la def tax 	1 "Low ed." 2 "Intermediate ed." ///
				3 "High ed. low SES" 4 "High ed. high SES"
	la val taxonomy1 tax
	la var taxonomy1 "SToWSES taxonomy of education and SES for Jordan and Tunisia (both parents basic or ft high skill)"


/****************************************************************************************************************************************************************
	
	Create TLMPS taxonomy
	
		Categories are: (1) Less than basic education
						(2) basic education 
						(3) Entered secondary, low SES (neither parents have basic education)
						(4) Entered secondary, +, high SES (at least one parent has a basic education)
	
****************************************************************************************************************************************************************/



	gen startsec=0 if country==788 & lastlevel!=.
	replace startsec=1 if country==788 & lastlevel>=8 & lastlevel<=12 
	la def banana 0 "No" 1 "Yes"
	la val startsec banana
	la var startsec "Y/N did respondent start secondary school? Tunisia only"
	

	gen ses_t1=.
	replace ses_t1=1 if med==1 & fed==1
	replace ses_t1=0 if med==0 & fed==0
	replace ses_t1=1 if med==1 & fed==0
	replace ses_t1=1 if med==0 & fed==1
	la val ses_t1 ses
	

	la def taxo_t 1 "L.T. basic" 2 "Basic"  3 "Start sec.+, L SES" 4 "Start sec.+, H SES"

	
	gen taxonomy_t=.
	replace taxonomy_t=1 if educ1d<=2 & educ1d!=. & country==788
	replace taxonomy_t=2 if educ1d==3 & country==788
	replace taxonomy_t=3 if startsec==1 & ses_t1==0 & country==788
	replace taxonomy_t=4 if startsec==1 & ses_t1==1 & country==788
	la val taxonomy_t taxo_t
	la var taxonomy_t "Tunisia education/SES taxonomy using `entering secondary school'"
	

/****************************************************************************************************************************************************************
	
	Construct 1st job outcome variable
		
		Now the same for men and women
		Based on the first three years after "school exit"
	
****************************************************************************************************************************************************************/
	
	gen worktaxon=.
	replace worktaxon=1 if evrwrk==1 & job1_01>=2 & job1_01<=5
	replace worktaxon=2 if evrwrk==1 & job1_01==1 & (job1_08_cl!=1 & job1_12!=1 & job1_08_cl!=. & job1_12!=.) & (job1_05>=3 & job1_05<=5)
	replace worktaxon=3 if evrwrk==1 & job1_01==1 & (job1_08_cl==1 | job1_12==1) & (job1_05>=3 & job1_05<=5)
	replace worktaxon=4 if evrwrk==1 & job1_01==1 & (job1_05>=1 & job1_05<=2)
	replace worktaxon=5 if evrwrk==0
	replace worktaxon=5 if job1_y > (last_ed + 3) & job1_y!=. & last_ed!=.
	
	label define Lworktaxon 1 "Family business" 2 "Private sector informal" 3 "Private sector formal" ///
	4 "Public Sector" 5 "Not yet worked" 
	label values worktaxon Lworktaxon
	
	tabu worktaxon country, miss
	
	
/****************************************************************************************************************************************************************
	
	Table A1: counts on taxonomy variables
	
****************************************************************************************************************************************************************/
	
	bys sex: table taxonomy_t generation if country==788 & expan_indiv!=. & worktaxon!=.
	bys sex: table taxonomy1 generation if country==400 & expan_indiv!=.  & worktaxon!=.
	bys sex: table taxonomy1 generation if country==818 & expan_indiv!=.  & worktaxon!=.
	

/****************************************************************************************************************************************************************
	
	Combine taxonomy variables
	
****************************************************************************************************************************************************************/


	gen taxonomy_tot = .
	replace taxonomy_tot = 1 if (taxonomy1==1 & country!=788) | (taxonomy_t==1 & country==788)
	replace taxonomy_tot = 2 if (taxonomy1==2 & country!=788) | (taxonomy_t==2 & country==788)
	replace taxonomy_tot = 3 if (taxonomy1==3 & country!=788) | (taxonomy_t==3  & country==788)
	replace taxonomy_tot = 4 if (taxonomy1==4 & country!=788) | (taxonomy_t==4  & country==788)
	
	la def taxi 1 "Low educ." 2 "Intermed. educ." 3 "High educ. low SES" 4 "High educ. high SES"
	la val taxonomy_tot taxi
	
	la var taxonomy_tot "Taxonomy variable for all three countries"
	
/****************************************************************************************************************************************************************
	
	New work code for females
	
****************************************************************************************************************************************************************/
	
	gen worktaxonf=.
	replace worktaxonf=1 if worktaxon>=1 & worktaxon<=3
	replace worktaxonf=2 if worktaxon==4
	replace worktaxonf=3 if worktaxon==5
	la def fem 1 "Private sector" 2 "Public sector" 3 "Not yet worked"
	la val worktaxonf fem
	
/****************************************************************************************************************************************************************
	
	SA 1: Birth cohorts (ages 25-34; 35-44; 45-54)
	
****************************************************************************************************************************************************************/
	
	recode age (0/24=.) (25/34=3) (35/44=2) (45/54=1) (55/199=.), gen(bcohort)
	
/****************************************************************************************************************************************************************
	
	SA 2: Relative, based on summing years of parental education
	
****************************************************************************************************************************************************************/

*Mother's/fathers years of education	

*Mother's
*Illiterate
gen myrsed=0 if mteducst!=.
*Reads and writes as three years of basic
replace myrsed=3 if mteducst==2
*Basic varies by country
replace myrsed=10 if mteducst==3 & country==400
replace myrsed=6 if mteducst==3 & country!=400
*Secondary as consistently 12
replace myrsed=12 if mteducst==4
*Post-secondary as consistently 14
replace myrsed=14 if mteducst==5
*University as consistently 16
replace myrsed=16 if mteducst==6
*Add one for Tunisia for secondary+
replace myrsed=myrsed+1 if country==788 & mteducst>=4 & mteducst<=6
	
*Father's
*Illiterate
gen fyrsed=0 if fteducst!=.
*Reads and writes as three years of basic
replace fyrsed=3 if fteducst==2
*Basic varies by country
replace fyrsed=10 if fteducst==3 & country==400
replace fyrsed=6 if fteducst==3 & country!=400
*Secondary as consistently 12
replace fyrsed=12 if fteducst==4
*Post-secondary as consistently 14
replace fyrsed=14 if fteducst==5
*University as consistently 16
replace fyrsed=16 if fteducst==6
*Add one for Tunisia for secondary+
replace fyrsed=fyrsed+1 if country==788 & fteducst>=4 & fteducst<=6	

*Parental years of education
gen pyrsed=fyrsed+myrsed

*By generation and country
gen dist_pyrsed=.

foreach num of numlist 1/3 {
	foreach num2 of numlist 818 400 788 {

sum pyrsed [aw=expan_indiv] if country==`num2' & generation==`num', detail
replace dist_pyrsed=`r(p90)' if country==`num2' & generation==`num'

	}
}

gen top_ses=pyrsed>=dist_pyrsed & pyrsed!=. & dist_pyrsed!=.

*Alternative taxonomy
gen alt_taxonomy=taxonomy_tot if taxonomy_tot==1 | taxonomy_tot==2
*High Ed., Low SES
replace alt_taxonomy=3 if (taxonomy_tot==3 | taxonomy_tot==4) & top_ses==0
*High Ed., High SES
replace alt_taxonomy=4 if (taxonomy_tot==3 | taxonomy_tot==4) & top_ses==1

la val alt_taxonomy tax1

table alt_taxonomy generation country


/****************************************************************************************************************************************************************
	
	SA 3: taxonomy based on father's occ. only (no parents' education')
	
****************************************************************************************************************************************************************/

	gen taxonSA3=.
	replace taxonSA3=1 if educ1d<=3 & educ1d!=.
	replace taxonSA3=2 if educ1d==4
	replace taxonSA3=3 if educ1d>=5 & educ1d<=7 & focc==0 
	replace taxonSA=4 if educ1d>=5 & educ1d<=7 & focc==1 | focc==.
	la def taxSA3 	1 "Low ed." 2 "Intermediate ed." ///
				3 "High ed. low SES" 4 "High ed. high SES"
	la val taxonSA3 taxSA3
	la var taxonSA3 "SA3 taxonomy of education and SES for Jordan and Tunisia (ft high skill)"


/****************************************************************************************************************************************************************
	
	Save data
	
****************************************************************************************************************************************************************/
			
			
	save "LMPS SToWSES clean v1.dta", replace
	

	
