/* 

	School to Work and Socioeconomic Status (STOWSES) Project
	Descriptives
	Colette Salemi, Caroline Krafft
	v16 
	Revised 2022.07.26 CK
	*/

/****************************************************************************************************************************************************************
	
	Figure: Distribution of SToWSES variable by generation: Egypt
	
****************************************************************************************************************************************************************/
	
	
	local country_year = "Egypt 2012"
	local country_code=818
	
	use "LMPS SToWSES clean v1.dta", clear

	set scheme s1mono	
	expand 2
	bysort indid: replace sex=3 if _n==2
	keep if country==`country_code'
			
	tabu taxonomy_tot, gen(taxonomy_tot_)		
	collapse taxonomy_tot_1-taxonomy_tot_4 [pw=expan_indiv], by(sex generation)
	egen combo=group(sex generation)
	keep if combo!=.
	reshape long taxonomy_tot_, i(combo) j(taxonomy_tot 1-4)
			
	gen taxonomy_prcnt=taxonomy_tot_*100
	drop taxonomy_tot_
	
	la def tax2 	1 "Low educ." 2 "Intermediate educ." 3 "High educ. low SES" 4 "High educ. high SES"
	la val taxonomy_tot tax2
	
		
	gr bar taxonomy_prcnt, over(taxonomy_tot) over(generation, label(angle(45)))  over(sex, relabel (1 "Men" 2 "Women" 3 "Total")) ///
	asyvars stack blabel(bar, format(%2.0f) size(3) pos(center) color(white)) ///
	plotregion(style(none))  ///
		bar(1, fcolor(gs11) lcolor(gs1) lwidth(.2)) ///
		bar(2, fcolor(gs8) lcolor(gs1) lwidth(.2)) ///
		bar(3, fcolor(gs5) lcolor(gs1) lwidth(.2)) ///
		bar(4, fcolor(gs1) lcolor(gs1) lwidth(.2)) ///
	ylabel(0 (20) 100,labs(4) nogrid) ytitle("Percentage", size(4))  ysize(10) xsize(20) ///
	legend(  rows(1) size(3)   ) title(`country_year')
	graph save "Graphs/Taxonomy by age and sex `country_year'.gph", replace
	

/****************************************************************************************************************************************************************
	
	Figure: Distribution of SToWSES variable by generation: Jordan
	
****************************************************************************************************************************************************************/
	
	
	local country_year = "Jordan 2016"
	local country_code=400
	
	use "LMPS SToWSES clean v1.dta", clear

	set scheme s1mono	
	expand 2
	bysort indid: replace sex=3 if _n==2
	keep if country==`country_code'
			
	tabu taxonomy_tot, gen(taxonomy_tot_)		
	collapse taxonomy_tot_1-taxonomy_tot_4 [pw=expan_indiv], by(sex generation)
	egen combo=group(sex generation)
	keep if combo!=.
	reshape long taxonomy_tot_, i(combo) j(taxonomy_tot 1-4)
			
	gen taxonomy_prcnt=taxonomy_tot_*100
	drop taxonomy_tot_
	
	la def tax2 	1 "Low educ." 2 "Intermediate educ." 3 "High educ. low SES" 4 "High educ. high SES"
	la val taxonomy_tot tax2
	
		
	gr bar taxonomy_prcnt, over(taxonomy_tot) over(generation, label(angle(45)))  over(sex, relabel (1 "Men" 2 "Women" 3 "Total")) ///
	asyvars stack blabel(bar, format(%2.0f) size(3) pos(center) color(white)) ///
	plotregion(style(none))  ///
		bar(1, fcolor(gs11) lcolor(gs1) lwidth(.2)) ///
		bar(2, fcolor(gs8) lcolor(gs1) lwidth(.2)) ///
		bar(3, fcolor(gs5) lcolor(gs1) lwidth(.2)) ///
		bar(4, fcolor(gs1) lcolor(gs1) lwidth(.2)) ///
	ylabel(0 (20) 100,labs(4) nogrid) ytitle("Percentage", size(4))  ysize(10) xsize(20) ///
	legend(  rows(1) size(3)   ) title(`country_year')
	graph save "Graphs/Taxonomy by age and sex `country_year'.gph", replace
	
	
/****************************************************************************************************************************************************************
	
	Figure: Distribution of SToWSES variable by generation: Tunisia
	
****************************************************************************************************************************************************************/
	
	local country_year = "Tunisia 2014"
	local country_code=788
	
	use "LMPS SToWSES clean v1.dta", clear

	set scheme s1mono	
	expand 2
	bysort indid: replace sex=3 if _n==2
	keep if country==`country_code'
			
	tabu taxonomy_tot, gen(taxonomy_tot_)		
	collapse taxonomy_tot_1-taxonomy_tot_4 [pw=expan_indiv], by(sex generation)
	egen combo=group(sex generation)
	keep if combo!=.
	reshape long taxonomy_tot_, i(combo) j(taxonomy_tot 1-4)
			
	gen taxonomy_prcnt=taxonomy_tot_*100
	drop taxonomy_tot_
	
	la def tax2 	1 "Low educ." 2 "Intermediate educ." 3 "High educ. low SES" 4 "High educ. high SES"
	la val taxonomy_tot tax2
	
		
	gr bar taxonomy_prcnt, over(taxonomy_tot) over(generation, label(angle(45)))  over(sex, relabel (1 "Men" 2 "Women" 3 "Total")) ///
	asyvars stack blabel(bar, format(%2.0f) size(3) pos(center) color(white)) ///
	plotregion(style(none))  ///
		bar(1, fcolor(gs11) lcolor(gs1) lwidth(.2)) ///
		bar(2, fcolor(gs8) lcolor(gs1) lwidth(.2)) ///
		bar(3, fcolor(gs5) lcolor(gs1) lwidth(.2)) ///
		bar(4, fcolor(gs1) lcolor(gs1) lwidth(.2)) ///
	ylabel(0 (20) 100,labs(4) nogrid) ytitle("Percentage", size(4))  ysize(10) xsize(20) ///
	legend(  rows(1) size(3)   ) title(`country_year')
	graph save "Graphs/Taxonomy by age and sex `country_year'.gph", replace
	

/****************************************************************************************************************************************************************
	
	Figure 2: Distribution of SToWSES variable by generation and country
	
			Notes:	Combines three graphs
	
****************************************************************************************************************************************************************/
	
	grc1leg  "Graphs/Taxonomy by age and sex Egypt 2012.gph" ///
	"Graphs/Taxonomy by age and sex Jordan 2016.gph" ///
	"Graphs/Taxonomy by age and sex Tunisia 2014.gph",  rows(1)
	graph display, xsize(12) ysize(6) 
	graph save "Graphs/Taxonomy by age and sex.gph", replace
	graph export "Graphs/Taxonomy by age and sex.png", width(900)  replace

	

	/****************************************************************************************************************************************************************
	
	Figure A1 - Household wealth by taxonomy and gender, Jordanian and Egyptian youngest generation
	
	
****************************************************************************************************************************************************************/

*Jordan - Extract household wealth in 2010

use "Original data/JLMPS 2016 panel v1.1.dta" , clear

keep qwealth_10 reltohd_10 panel_wt_10_16 indid_16 

encode indid_16, gen(missing)
drop if missing==.
drop missing

gen country = "400"
egen indid = concat(country indid_16)

drop country indid_16
isid indid

keep if qwealth_10!=.

save "Additional data/Jordan 2010 qwealth.dta", replace

*Merge and graph

use "LMPS SToWSES clean v1.dta", clear

drop _merge
merge m:1 indid using "Additional data/Jordan 2010 qwealth.dta"

*Restrict to only Jordanians with 2010 data
keep if _merge==3
drop _merge

*How many with parents in 2010?

tabu reltohd_10 if generation==3 [aw=panel_wt_10_16], miss
*83% of Jordanians in the youngest school exit cohort were living with their parents in 2010

*Taxonomy and wealth for the youngest generation
tab taxonomy_tot qwealth_10 if generation==3 & reltohd_10==3 [aw=panel_wt_10_16], row nofreq
	
set scheme s1mono	


la def wealth 1 "Lowest" 2 "Second" 3 "Third" 4 "Fourth" 5 "Highest"
la val qwealth_10 wealth

*Graph
catplot qwealth_10 if generation==3 & reltohd_10==3 [aw=panel_wt_10_16], percent(taxonomy_tot) over(taxonomy_tot, label(angle(45)))  ///
asyvars stack blabel(bar, format(%2.0f) size(3) pos(center) color(white)) ///
plotregion(style(none))  ///
	bar(1, fcolor(gs12) lcolor(gs1) lwidth(.2)) ///
	bar(2, fcolor(gs9) lcolor(gs1) lwidth(.2)) ///
	bar(3, fcolor(gs6) lcolor(gs1) lwidth(.2)) ///
	bar(4, fcolor(gs3) lcolor(gs1) lwidth(.2)) ///
	bar(5, fcolor(gs1) lcolor(gs1) lwidth(.2)) ///
ylabel(0 (20) 100,labs(4) nogrid) ytitle("Percentage", size(4))  ysize(14) xsize(20) ///
legend(  rows(1)   order(5 4 3 2 1) size(3)   ) title("Jordan") b1title(" ") recast(bar)


graph save "Graphs/Taxonomy and parental wealth Jordan youngest.gph", replace
graph export "Graphs/Taxonomy and parental wealth Jordan youngest.png", width(900)  replace


	

*Egypt - Extract household wealth in 2006

use "Original data/elmps 2018 panel 98_18 v2.0.dta" , clear

keep qwealth_06 reltohd_06 panel_wt_06_12 indid_12

encode indid_12, gen(missing)
drop if missing==.
drop missing

gen country = "818"
egen indid = concat(country indid_12)

drop country indid_12
isid indid

keep if qwealth_06!=.

save "Additional data/Egypt 2006 qwealth.dta", replace


*Merge and graph

use "LMPS SToWSES clean v1.dta", clear

drop _merge
merge m:1 indid using "Additional data/Egypt 2006 qwealth.dta"

*Restrict to only Jordanians with 2010 data
keep if _merge==3
drop _merge

*How many with parents in 2010?

tabu reltohd_06 if generation==3 [aw=panel_wt_06_12], miss
*78% of Egyptians in the youngest school exit cohort were living with their parents in 2006

*Taxonomy and wealth for the youngest generation
tab taxonomy_tot qwealth_06 if generation==3 & reltohd_06==3 [aw=panel_wt_06_12], row nofreq
	
la def wealth 1 "Lowest" 2 "Second" 3 "Third" 4 "Fourth" 5 "Highest"
la val qwealth_06 wealth

*Graph
catplot qwealth_06 if generation==3 & reltohd_06==3 [aw=panel_wt_06_12], percent(taxonomy_tot) over(taxonomy_tot, label(angle(45)))  ///
asyvars stack blabel(bar, format(%2.0f) size(3) pos(center) color(white)) ///
plotregion(style(none))  ///
	bar(1, fcolor(gs12) lcolor(gs1) lwidth(.2)) ///
	bar(2, fcolor(gs9) lcolor(gs1) lwidth(.2)) ///
	bar(3, fcolor(gs6) lcolor(gs1) lwidth(.2)) ///
	bar(4, fcolor(gs3) lcolor(gs1) lwidth(.2)) ///
	bar(5, fcolor(gs1) lcolor(gs1) lwidth(.2)) ///
ylabel(0 (20) 100,labs(4) nogrid) ytitle("Percentage", size(4))  ysize(14) xsize(20) ///
legend(  rows(1)   order(5 4 3 2 1) size(3)   ) title("Egypt") b1title(" ") recast(bar)


graph save "Graphs/Taxonomy and parental wealth Egypt youngest.gph", replace
graph export "Graphs/Taxonomy and parental wealth Egypt youngest.png", width(900)  replace

*Combined graph
grc1leg "Graphs/Taxonomy and parental wealth Egypt youngest.gph" "Graphs/Taxonomy and parental wealth Jordan youngest.gph"

graph save "Graphs/Taxonomy and parental wealth youngest.gph", replace
graph export "Graphs/Taxonomy and parental wealth youngest.png", width(900)  replace


/****************************************************************************************************************************************************************
	
	Table A6/7 - Main results, descriptive table: percentage by country, sex, generation, taxonomy
	
****************************************************************************************************************************************************************/

use "LMPS SToWSES clean v1.dta", clear

bysort country sex taxonomy_tot: tabu  generation  worktaxon if generation!=. [aw=expan_indiv], row nofreq

capture erase "Graphs/Distribution of main outcomes men.xls"
capture erase "Graphs/Distribution of main outcomes W.xls"

	foreach location of numlist 818 400 788 {
		foreach group of numlist 1/4 {
			
*Men
tabout generation worktaxon if sex==1 & country==`location' & taxonomy_tot==`group' [aw=expan_indiv] using "Graphs/Distribution of main outcomes men.xls", append c(row) 

*Women
tabout generation worktaxonf if sex==2 & country==`location' & taxonomy_tot==`group' [aw=expan_indiv] using "Graphs/Distribution of main outcomes W.xls", append c(row) 
		}
	}

	/****************************************************************************************************************************************************************
	
	Table A8/9 - Birth cohort results, descriptive table: percentage by country, sex, birth cohort, taxonomy
	
****************************************************************************************************************************************************************/

use "LMPS SToWSES clean v1.dta", clear

bysort country sex taxonomy_tot: tabu  bcohort  worktaxon if bcohort!=. [aw=expan_indiv], row nofreq

capture erase "Graphs/Distribution of bcohort men.xls"
capture erase "Graphs/Distribution of bcohort W.xls"

	foreach location of numlist 818 400 788 {
		foreach group of numlist 1/4 {
			
*Men
tabout bcohort worktaxon if sex==1 & country==`location' & taxonomy_tot==`group' [aw=expan_indiv] using "Graphs/Distribution of bcohort men.xls", append c(row) 

*Women
tabout bcohort worktaxonf if sex==2 & country==`location' & taxonomy_tot==`group' [aw=expan_indiv] using "Graphs/Distribution of bcohort W.xls", append c(row) 
		}
	}

/****************************************************************************************************************************************************************
	
	Table A10/11 - SA relative results, descriptive table: percentage by country, sex, generation, alternative taxonomy
	
****************************************************************************************************************************************************************/

use "LMPS SToWSES clean v1.dta", clear

bysort country sex alt_taxonomy: tabu  generation  worktaxon if generation!=. [aw=expan_indiv], row nofreq

capture erase "Graphs/Distribution of alt men.xls"
capture erase "Graphs/Distribution of alt W.xls"

	foreach location of numlist 818 400 788 {
		foreach group of numlist 1/4 {
			
*Men
tabout generation worktaxon if sex==1 & country==`location' & alt_taxonomy==`group' [aw=expan_indiv] using "Graphs/Distribution of alt men.xls", append c(row) 

*Women
tabout generation worktaxonf if sex==2 & country==`location' & alt_taxonomy==`group' [aw=expan_indiv] using "Graphs/Distribution of alt W.xls", append c(row) 
		}
	}
	

/****************************************************************************************************************************************************************
	
	Table A12/A13 - SA relative results, descriptive table: percentage by country, sex, generation, alternative taxonomy
	using only father's education
	
****************************************************************************************************************************************************************/

use "LMPS SToWSES clean v1.dta", clear



bysort country sex taxonSA3: tabu  generation  worktaxon if generation!=. [aw=expan_indiv], row nofreq

bysort country taxonSA3: tabu  generation  worktaxon if sex==1
bysort country taxonSA3: tabu  generation  worktaxonf if sex==2 
cap log close

bysort country taxonomy_tot: tabu  generation  worktaxon if sex==1
bysort country taxonomy_tot: tabu  generation  worktaxonf if sex==2 
cap log close



capture erase "Graphs/Distribution of alt men 2.xls"
capture erase "Graphs/Distribution of alt W 2.xls"

	foreach location of numlist 818 400 788 {
		foreach group of numlist 1/4 {
			
*Men
tabout generation worktaxon if sex==1 & country==`location' & taxonSA3==`group' [aw=expan_indiv] using"Graphs/Distribution of alt men 2.xls", append c(row) 

*Women
tabout generation worktaxonf if sex==2 & country==`location' & taxonSA3==`group' [aw=expan_indiv] using "Graphs/Distribution of alt W 2.xls", append c(row) 
		}
	}
	

	
	/****************************************************************************************************************************************************************
	
	Tabular - counts of women in different STOWSES work outcomes
	
****************************************************************************************************************************************************************/

use "LMPS SToWSES clean v1.dta", clear

bys generation: ta worktaxon country if sex==2

*Only 30/37 women from the youngest generation in Jordan/Tunisia had a private sector informal job
*Only 13/33 women from the middle generation in Jordan/Tunisia had a private sector informal job
*Only 5/28/78 women in the oldest generation in Jordan/Tunisia had a private sector informal job

*Counts are even worse for family businesses
*In Jordan, across cohorts, the number of women with a family business as first job is 7 or fewer 
